=== modified file 'bzrlib/export/zip_exporter.py'
--- bzrlib/export/zip_exporter.py	2005-12-01 17:11:25 +0000
+++ bzrlib/export/zip_exporter.py	2005-12-01 17:36:29 +0000
@@ -54,7 +54,7 @@
                 zipf.writestr(zinfo, tree.get_file_text(file_id))
             elif ie.kind == "directory":
                 zinfo = zipfile.ZipInfo(
-                            filename=str(pathjoin(root, dp)+os.sep),
+                            filename=str(pathjoin(root, dp)+'/'),
                             date_time=now)
                 zinfo.compress_type = compression
                 zipf.writestr(zinfo,'')

=== modified file 'bzrlib/externalcommand.py'
--- bzrlib/externalcommand.py	2005-12-01 17:11:25 +0000
+++ bzrlib/externalcommand.py	2005-12-01 17:36:29 +0000
@@ -48,20 +48,17 @@
     def __init__(self, path):
         self.path = path
 
-
     def name(self):
-        return self.path.split(os.sep)[-1]
-
+        return os.path.basename(self.path)
 
     def run(self, *args, **kwargs):
         raise NotImplementedError('should not be called on %r' % self)
 
-
     def run_argv(self, argv):
         return os.spawnv(os.P_WAIT, self.path, [self.path] + argv)
 
-
     def help(self):
         m = 'external command from %s\n\n' % self.path
         pipe = os.popen('%s --help' % self.path)
         return m + pipe.read()
+

=== modified file 'bzrlib/hashcache.py'
--- bzrlib/hashcache.py	2005-11-10 03:03:53 +0000
+++ bzrlib/hashcache.py	2005-12-01 17:36:29 +0000
@@ -35,6 +35,7 @@
 from bzrlib.osutils import sha_file
 from bzrlib.trace import mutter, warning
 from bzrlib.atomicfile import AtomicFile
+from bzrlib.osutils import pathjoin
 
 
 FP_MODE_COLUMN = 5
@@ -104,7 +105,7 @@
     def cache_file_name(self):
         # FIXME: duplicate path logic here, this should be 
         # something like 'branch.controlfile'.
-        return os.sep.join([self.basedir, '.bzr', 'stat-cache'])
+        return pathjoin(self.basedir, '.bzr', 'stat-cache')
 
     def clear(self):
         """Discard all cached information.
@@ -125,7 +126,7 @@
         prep.sort()
         
         for inum, path, cache_entry in prep:
-            abspath = os.sep.join([self.basedir, path])
+            abspath = pathjoin(self.basedir, path)
             fp = _fingerprint(abspath)
             self.stat_count += 1
             
@@ -141,7 +142,7 @@
     def get_sha1(self, path):
         """Return the sha1 of a file.
         """
-        abspath = os.sep.join([self.basedir, path])
+        abspath = pathjoin(self.basedir, path)
         self.stat_count += 1
         file_fp = _fingerprint(abspath)
         

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2005-12-01 17:11:25 +0000
+++ bzrlib/inventory.py	2005-12-01 17:36:29 +0000
@@ -987,12 +987,12 @@
         >>> i = Inventory()
         >>> e = i.add(InventoryDirectory('src-id', 'src', ROOT_ID))
         >>> e = i.add(InventoryFile('foo-id', 'foo.c', parent_id='src-id'))
-        >>> print i.id2path('foo-id').replace(os.sep, '/')
+        >>> print i.id2path('foo-id')
         src/foo.c
         """
         # get all names, skipping root
         p = [self._byid[fid].name for fid in self.get_idpath(file_id)[1:]]
-        return os.sep.join(p)
+        return pathjoin(*p)
             
 
 

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2005-12-01 17:25:16 +0000
+++ bzrlib/osutils.py	2005-12-01 17:36:29 +0000
@@ -235,8 +235,8 @@
     if dir == '':
         return True
 
-    if dir[-1] != os.sep:
-        dir += os.sep
+    if dir[-1] != '/':
+        dir += '/'
 
     return fname.startswith(dir)
 
@@ -500,7 +500,7 @@
         # to branch anymore.
         raise NotBranchError("path %r is not within branch %r" % (rp, base))
 
-    return os.sep.join(s)
+    return pathjoin(*s)
 
 
 

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2005-12-01 17:11:25 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2005-12-01 17:36:29 +0000
@@ -668,7 +668,7 @@
         # the ordering is not defined at the moment
         results = sorted(out.rstrip('\n').split('\n'))
         self.assertEquals(['added dir',
-                           'added dir'+os.sep+'sub.txt',
+                           'added dir/sub.txt',
                            'added top.txt',],
                           results)
 
@@ -715,7 +715,7 @@
         self.build_tree(['inertiatic/', 'inertiatic/esp'])
         self.assertEquals(self.capture('unknowns'), 'inertiatic\n')
         self.run_bzr('add', '--no-recurse', 'inertiatic')
-        self.assertEquals(self.capture('unknowns'), 'inertiatic'+os.sep+'esp\n')
+        self.assertEquals(self.capture('unknowns'), 'inertiatic/esp\n')
         self.run_bzr('add', 'inertiatic/esp')
         self.assertEquals(self.capture('unknowns'), '')
 

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2005-11-30 00:25:50 +0000
+++ bzrlib/tests/test_branch.py	2005-12-01 17:36:29 +0000
@@ -49,7 +49,7 @@
         os.mkdir('b2')
         b1 = Branch.initialize('b1')
         b2 = Branch.initialize('b2')
-        file(os.sep.join(['b1', 'foo']), 'w').write('hello')
+        file('b1/foo'), 'w').write('hello')
         b1.working_tree().add(['foo'], ['foo-id'])
         b1.working_tree().commit('lala!', rev_id='revision-1', allow_pointless=False)
 

=== modified file 'bzrlib/tests/test_commit.py'
--- bzrlib/tests/test_commit.py	2005-11-30 00:25:50 +0000
+++ bzrlib/tests/test_commit.py	2005-12-01 17:36:29 +0000
@@ -201,8 +201,7 @@
         self.check_inventory_shape(b.get_revision_inventory(r3),
                                    ['a', 'a/hello', 'a/b'])
 
-        b.working_tree().move([os.sep.join(['a', 'hello'])],
-               os.sep.join(['a', 'b']))
+        b.working_tree().move(['a/hello'], 'a/b')
         r4 = 'test@rev-4'
         b.working_tree().commit('four', rev_id=r4, allow_pointless=False)
         self.check_inventory_shape(b.working_tree().read_working_inventory(),

=== modified file 'bzrlib/tests/test_log.py'
--- bzrlib/tests/test_log.py	2005-11-30 00:25:50 +0000
+++ bzrlib/tests/test_log.py	2005-12-01 17:36:29 +0000
@@ -57,8 +57,8 @@
             expected = kw.get(n, [])
 
             # tests are written with unix paths; fix them up for windows
-            if os.sep != '/':
-                expected = [x.replace('/', os.sep) for x in expected]
+            #if os.sep != '/':
+            #    expected = [x.replace('/', os.sep) for x in expected]
 
             # strip out only the path components
             got = [x[0] for x in getattr(delta, n)]

